#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-F4ppcJ8ED3FD8lTRjpXVOI
key:                  coinbase-pro-0.9.3.2-F4ppcJ8ED3FD8lTRjpXVOI
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  f9c2cd36d52345477d74a702617be90b
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-F4ppcJ8ED3FD8lTRjpXVOI
depends:
    HsOpenSSL-0.11.7.9-BrljXZquC3R4fQ7boVyqZl
    aeson-2.2.2.0-Bvq1RZLTB982HJyF7e96XU
    aeson-casing-0.2.0.0-6pzskjgCdRX4POLTRdEqwZ
    async-2.2.6-L49doqolqOiLsPy3OvdI1h base-4.18.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-LRRhJ0VKVMSCVJ50Q8kQqW exceptions-0.10.7
    http-api-data-0.6.1-Ila4hB4mSfHDfimSRxfLrT
    http-client-0.7.19-BV4AT2QZinhAZt9DyDMIrY
    http-client-tls-0.3.6.4-4PkwIHdSyLZEv9DDXogskJ
    http-streams-0.8.9.9-48JNtO25nC6JAxTzPHnTib
    http-types-0.12.4-BfnwqLIFvgHNb88uBZwW9
    io-streams-1.5.2.2-HUCElSXCJdwErApRr6tdrM
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-3.1.4.0-tP2o8Wry2b3nJpuPXPLoR
    servant-0.20.3.0-9GSVLIq6JVd9kiQ6AqKBni
    servant-client-0.20.3.0-7PHRp0WSqYE4qYNWUmgvB8
    servant-client-core-0.20.3.0-7oODArJ9N48DvjBb0UYpVr
    tasty-1.5.2-OganKtPyxcCar8CMuVw5S
    tasty-hunit-0.10.2-4kXudE9ATCQ36cmsDc0Io7 text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unagi-streams-0.2.7-Auu01CTtvyiHkN0ky31xSr
    unordered-containers-0.2.20.1-ITIVaOGw28dDFkmcPJu0s3
    uuid-1.3.16.1-2FavIqrolec41NAkrHXRfw
    vector-0.13.2.0-9FXioZw2Nye8eueJzIuHK4
    websockets-0.12.7.3-3UDBOHXnlrmKwWoKJ5GUHC
    wuss-2.0.1.7-IMMwwNcG2YTHP9DI2yeJX4

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

